aboutsummaryrefslogtreecommitdiff
path: root/gdb/utils.h
diff options
context:
space:
mode:
authorTom Tromey <tom@tromey.com>2022-01-02 11:36:44 -0700
committerTom Tromey <tom@tromey.com>2022-03-29 12:46:24 -0600
commit0426ad513f93bb1c5805988e60d6f87fbe738860 (patch)
tree6ad0f94f9b2a907623df38db9dd7727fe80f5d51 /gdb/utils.h
parent19a7b8ab871b92dee32a0ebffe274388d3426564 (diff)
downloadfsf-binutils-gdb-0426ad513f93bb1c5805988e60d6f87fbe738860.zip
fsf-binutils-gdb-0426ad513f93bb1c5805988e60d6f87fbe738860.tar.gz
fsf-binutils-gdb-0426ad513f93bb1c5805988e60d6f87fbe738860.tar.bz2
Unify gdb puts functions
Now that filtered and unfiltered output can be treated identically, we can unify the puts family of functions. This is done under the name "gdb_puts". Most of this patch was written by script.
Diffstat (limited to 'gdb/utils.h')
-rw-r--r--gdb/utils.h8
1 files changed, 3 insertions, 5 deletions
diff --git a/gdb/utils.h b/gdb/utils.h
index 09c971f..dc76da4 100644
--- a/gdb/utils.h
+++ b/gdb/utils.h
@@ -233,9 +233,7 @@ extern void set_screen_width_and_height (int width, int height);
here are the styling formatters: '%p[', '%p]' and '%ps'. See
ui_out::message for details. */
-extern void fputs_filtered (const char *, struct ui_file *);
-
-extern void fputs_unfiltered (const char *, struct ui_file *);
+extern void gdb_puts (const char *, struct ui_file *);
extern int fputc_filtered (int c, struct ui_file *);
@@ -243,7 +241,7 @@ extern int fputc_unfiltered (int c, struct ui_file *);
extern int putchar_filtered (int c);
-extern void puts_filtered (const char *);
+extern void gdb_puts (const char *);
extern void puts_filtered_tabular (char *string, int width, int right);
@@ -284,7 +282,7 @@ extern void vfprintf_styled (struct ui_file *stream,
va_list args)
ATTRIBUTE_PRINTF (3, 0);
/* Like fputs_filtered, but styles the output according to STYLE, when
appropriate. */
extern void fputs_styled (const char *linebuffer,
@@ -284,7 +282,7 @@ extern void vfprintf_styled (struct ui_file *stream,
va_list args)
ATTRIBUTE_PRINTF (3, 0);
-/* Like fputs_filtered, but styles the output according to STYLE, when
+/* Like gdb_puts, but styles the output according to STYLE, when
appropriate. */
extern void fputs_styled (const char *linebuffer,